@@ -1,5 +1,5 @@
 #!@@PERL@@
-# $Id: slonik_subscribe_set.pl,v 1.3.2.1 2009-08-17 17:09:59 devrim Exp $
+# 
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
@@ -36,19 +36,13 @@ if ($node =~ /^(?:node)?(\d+)$/) {
   die $USAGE;
 }
 
-if ($set =~ /^(?:set)?(\d+)$/) {
-  $set = $1;
-} else {
-  print "Need to specify set!\n";
-  die $USAGE;
-}
-
-get_set($set) or die "Non-existent set specified.\n";
+die $USAGE unless $set;
+$set = get_set($set) or die "Non-existent set specified.\n";
 
 my $slonik = '';
 
 $slonik .= genheader();
-$slonik .= "  try {\n";
+$slonik .= " \n";
 
 if ($DSN[$node]) {
   my $provider = $SET_ORIGIN;
@@ -66,9 +60,5 @@ if ($DSN[$node]) {
   die "Node $node not found\n";
 }
 
-$slonik .= "  }\n";
-$slonik .= "  on error {\n";
-$slonik .= "    exit 1;\n";
-$slonik .= "  }\n";
 $slonik .= "  echo 'Subscribed nodes to set $set';\n";
 run_slonik_script($slonik);
